@@ -7,6 +7,10 @@
 #'   \item Static map (ggplot), which can be easily exported in \code{.pdf} objects.
 #' }
 #'
+#' @param data Object of class \code{tbl_df}, \code{tbl} and \code{data.frame}.
+#' The raw Invalsi survey data that has to be filtered, obtained as output of the \code{\link{Get_Invalsi_IS}} function.
+#' If \code{NULL}, it will be downloaded automatically, but not saved in the global environment.
+#' \code{NULL} by default
 #'
 #' @param Year Numeric or character value. Reference school year for the data (last available is 2022/23).
 #' Available in the formats: \code{2022}, \code{"2021/2022"}, \code{202122}, \code{20212022}. \code{2022} by default
@@ -26,13 +30,9 @@
 #' @param plot Character. The type of map to display; either \code{"mapview"} for interactive maps, or \code{"ggplot"} for static maps. \code{"mapview"} by default.
 #' @param pal Character. The palette to use if the \code{"mapview"} mode is chose. \code{"Blues"} by default.
 #' @param WLE Logical. Whether the variable to chose should be the average WLE score rather that the percentage of sufficient tests, if both are available. \code{FALSE} by default
-#' @param col.rev Logical. Whether the scale of the colour palette should be reverted or not, if the \code{mapview} mode is chosen. \code{FALSE} by default
+#' @param col_rev Logical. Whether the scale of the colour palette should be reverted or not, if the \code{mapview} mode is chosen. \code{FALSE} by default
 #' @param popup_height Numeric. The height of the popup table in terms of pixels if the \code{"mapview"} mode is chosen. \code{200} by default.
 #' @param verbose Logical. If \code{TRUE}, the user keeps track of the main underlying operations. \code{TRUE} by default.
-#' @param data Object of class \code{tbl_df}, \code{tbl} and \code{data.frame}.
-#' The raw Invalsi survey data that has to be filtered, obtained as output of the \code{\link{Get_Invalsi_IS}} function.
-#' If \code{NULL}, it will be downloaded automatically, but not saved in the global environment.
-#' \code{NULL} by default
 #' @param input_shp Object of class \code{sf}, \code{tbl_df}, \code{tbl}, \code{data.frame}. The relevant shapefiles of Italian administrative boudaries,
 #' at the selected level of detail (LAU or NUTS-3). If \code{NULL}, it is downloaded automatically but not saved in the global environment. \code{NULL} by default.
 #' @param autoAbort Logical. In case any data must be retrieved, whether to automatically abort the operation and return NULL in case of missing internet connection or server response errors. \code{FALSE} by default.
@@ -59,9 +59,9 @@
 #'
 #' @export
 
-Map_Invalsi <- function(Year = 2023, data = NULL, subj_toplot = "ITA", grade = 8, level = "LAU",
+Map_Invalsi <- function(data = NULL, Year = 2023, subj_toplot = "ITA", grade = 8, level = "LAU",
                         main = "", main_pos = "top", region_code = c(1:20), plot="mapview", pal = "Blues",
-                        WLE = FALSE, col.rev = FALSE, popup_height = 200, verbose = TRUE,
+                        WLE = FALSE, col_rev = FALSE, popup_height = 200, verbose = TRUE,
                         input_shp = NULL, autoAbort = FALSE){
 
   if (length(subj_toplot) > 1){
@@ -131,7 +131,7 @@ Map_Invalsi <- function(Year = 2023, data = NULL, subj_toplot = "ITA", grade = 8
     fieldname <- "M_Mathematics"
   }
 
-  if (level %in% c("Municipality", "LAU") ){
+  if (toupper(level) %in% c("MUNICIPALITY", "LAU", "NUTS-4") ){
     shp <- input_shp %>% dplyr::select(.data$COD_REG, .data$COD_PROV, .data$PRO_COM_T) %>%
       rename_by_idx(c(1,2,3), into=c("Region_code", "Province_code", "Municipality_code"))
   } else {
@@ -148,7 +148,7 @@ Map_Invalsi <- function(Year = 2023, data = NULL, subj_toplot = "ITA", grade = 8
   if (plot =="mapview"){
 
     n <- length(unique(res$X)) - 1
-    if( col.rev == FALSE){
+    if( col_rev == FALSE){
       brew <- grDevices::hcl.colors(n, palette = pal)
     } else {
       brew <- rev(grDevices::hcl.colors(n, palette = pal))
