@@ -103,7 +103,7 @@ Map_School_Buildings <- function (data = NULL, field, order = NULL,  level = "LA
 
   if(!is.data.frame(data)){
     if(any(grepl("missing", names(data)))){
-      if(level %in% c("LAU", "Municipality")){
+      if(toupper(level) %in% c("LAU", "MUNICIPALITY", "NUTS-4")){
         DB <- data$Municipality_data %>%
           dplyr::left_join(data$Municipality_missing, by = c("Municipality_code", "Order"))
       } else {
@@ -111,7 +111,7 @@ Map_School_Buildings <- function (data = NULL, field, order = NULL,  level = "LA
           dplyr::left_join(data$Province_missing, by = c("Province_code", "Order"))
       }
     } else {
-      if(level %in% c("LAU", "Municipality")){
+      if(toupper(level) %in% c("LAU", "MUNICIPALITY", "NUTS-4")){
         DB <- data$Municipality_data
       } else DB <- data$Province_data
     }
@@ -142,15 +142,9 @@ Map_School_Buildings <- function (data = NULL, field, order = NULL,  level = "LA
     }
   }
 
-#  if(level %in% c ("LAU", "Municipality")){
-#    Mun_shp <- input_shp
-#  } else if(level %in% c("NUTS-3", "Province") ) Prov_shp <- input_shp else {
-#    stop("Please, choose either 'LAU'('Municipality') or 'NUTS-3' ('Province') as level")
-#  }
-
   if(verbose) cat("Setting target variables... \n")
 
-  if (level %in% c("LAU", "Municipality") ){
+  if (toupper(level) %in% c("LAU", "MUNICIPALITY", "NUTS-4")){
     dat.R <- DB %>% dplyr::filter(.data$Order != "NR")
 
     # formerly across(all_of(c(3:ncol(.)-4)))
@@ -178,6 +172,24 @@ Map_School_Buildings <- function (data = NULL, field, order = NULL,  level = "LA
 
   } else {
 
+    if("Municipality_code" %in% names(DB)){
+      startgroup <- min(
+        which(
+          unlist(
+            lapply(dplyr::select(DB, -.data$Province_code),
+                   function(x) any(is.numeric(x)))))) + 1
+      DB <- DB %>% Group_Count(
+        groupcol = c("Province_code", "Province_initials", "Order"), FUN =MeanOrMode,
+        startgroup = startgroup, countname = "nmun")
+      if("nbuildings" %in% names(DB)){
+        DB <- DB %>% dplyr::mutate(nmun = .data$nmun * .data$nbuildings) %>%
+          dplyr::select(-.data$nbuildings) %>%
+          dplyr::rename(nbuildings = .data$nmun)
+      } else {
+        DB <- DB %>% dplyr::select(-.data$nmun)
+      }
+    }
+
     dat.R <- DB %>% dplyr::filter(.data$Order != "NR")
 
     if (is.null(order)){
@@ -241,7 +253,9 @@ Map_School_Buildings <- function (data = NULL, field, order = NULL,  level = "LA
     }
   } else {
 
-    n <- length(unique(unlist(sf::st_drop_geometry(res[,nfield])))) - 1
+    #n <- length(unique(unlist(sf::st_drop_geometry(res[,nfield])))) - 1
+    n <- length(unique(unlist(dplyr::select(dplyr::filter(
+      dat.R, .data$Province_code %in% res$Province_code), field)))) - 1
     if (col_rev == FALSE) {
       brew <- grDevices::hcl.colors(n, palette = pal)
     } else {
